using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using SelectorRadioButton.Data;
using SelectorRadioButton.Data.OrdersDataSetTableAdapters;
using SelectorRadioButton.Controls;

namespace SelectorRadioButton
{
    public partial class Default : System.Web.UI.Page
    {
        # region Private Constants
        //-----------------------------------------------------------------------------------------------------
        private const string SessionOrders = "Orders";
        //-----------------------------------------------------------------------------------------------------
        # endregion

        #region Public Constants
        //-----------------------------------------------------------------------------------------------------
        public const string SelectedOrderIDField = "SelectedOrderID";
        //-----------------------------------------------------------------------------------------------------
        #endregion

        #region Private Instance Variables
        //-----------------------------------------------------------------------------------------------------
        private int? _preSelectedOrderID = null;
        //-----------------------------------------------------------------------------------------------------
        #endregion

        #region Public Properties
        //-----------------------------------------------------------------------------------------------------
        public int? PreSelectedOrderID
        {
            get { return _preSelectedOrderID; }
        }
        //-----------------------------------------------------------------------------------------------------
        #endregion

        #region Event Handlers
        //----------------------------------------------------------------------------------------------------
        protected void Page_Load(object sender, EventArgs e)
        {
            lblMessage.Text = string.Empty;
            _preSelectedOrderID = null;

            if (!IsPostBack)
            {
                // Retrieve the Orders from the database, set the sort order and save in Session.

                //OrdersTableAdapter ordersTableAdapter = new OrdersTableAdapter();
                //OrdersDataSet.OrdersDataTable ordersDataTable = ordersTableAdapter.GetData();

                OrdersDataSet ordersDataSet = new OrdersDataSet();
                ordersDataSet.ReadXml(System.IO.Path.Combine(Request.PhysicalApplicationPath, "Data\\Orders.xml"));
                OrdersDataSet.OrdersDataTable ordersDataTable = ordersDataSet.Orders;

                ordersDataTable.DefaultView.Sort = ordersDataTable.OrderIDColumn.ColumnName;
                
                Session[SessionOrders] = ordersDataTable;
            }

        }

        protected void Page_PreRender(object sender, EventArgs e)
        {
            // Get the Orders from Session, add columns to the GridView, bind the GridView

            OrdersDataSet.OrdersDataTable ordersDataTable = (OrdersDataSet.OrdersDataTable)Session[SessionOrders];

            SelectorRadioButtonField selectorRadioButtonField = new SelectorRadioButtonField(SelectedOrderIDField, ordersDataTable.OrderIDColumn.ColumnName);
            selectorRadioButtonField.AttributeBindings.Add("shipRegion", ordersDataTable.ShipRegionColumn.ColumnName);
            selectorRadioButtonField.OnClick = "enableDisableButtons(this)";
            selectorRadioButtonField.UnBoundAttributes.Add(HtmlTextWriterAttribute.Title.ToString(), "Click to select");
            OrdersGridView.Columns.Add(selectorRadioButtonField);

            BoundField boundField;

            boundField = new BoundField();
            boundField.DataField = ordersDataTable.OrderIDColumn.ColumnName;
            boundField.HeaderText = "Order ID";
            OrdersGridView.Columns.Add(boundField);

            boundField = new BoundField();
            boundField.DataField = ordersDataTable.CustomerIDColumn.ColumnName;
            boundField.HeaderText = "Customer ID";
            OrdersGridView.Columns.Add(boundField);

            boundField = new BoundField();
            boundField.DataField = ordersDataTable.OrderDateColumn.ColumnName;
            boundField.HeaderText = "Order Date";
            boundField.DataFormatString = "{0:dd MMM yyyy}";
            boundField.HtmlEncode = false;
            OrdersGridView.Columns.Add(boundField);

            boundField = new BoundField();
            boundField.DataField = ordersDataTable.ShipRegionColumn.ColumnName;
            boundField.HeaderText = "Ship Region";
            OrdersGridView.Columns.Add(boundField);

            boundField = new BoundField();
            boundField.DataField = ordersDataTable.ShipCityColumn.ColumnName;
            boundField.HeaderText = "Ship City";
            OrdersGridView.Columns.Add(boundField);

            boundField = new BoundField();
            boundField.DataField = ordersDataTable.ShipCountryColumn.ColumnName;
            boundField.HeaderText = "Ship Country";
            OrdersGridView.Columns.Add(boundField);

            OrdersGridView.DataSource = ordersDataTable;
            OrdersGridView.DataBind();
        }

        protected void OrdersGridView_PageIndexChanging(object sender, GridViewPageEventArgs e)
        {
            OrdersGridView.PageIndex = e.NewPageIndex;
        }

        protected void cmdViewShipRegion_Click(object sender, EventArgs e)
        {
            // Get the Order ID of the selected Order, find the Order in the 
            // Orders that are saved in Session, set the message label to a 
            // message that includes the Ship Region of the Order.

            _preSelectedOrderID = GetSelectedOrderID();

            OrdersDataSet.OrdersDataTable ordersDataTable = (OrdersDataSet.OrdersDataTable)Session[SessionOrders];

            OrdersDataSet.OrdersRow ordersRow = ordersDataTable.FindByOrderID(_preSelectedOrderID.Value);

            lblMessage.Text = "You clicked View Ship Region for region " + ordersRow.ShipRegion;
        }
        //----------------------------------------------------------------------------------------------------
        #endregion

        #region Private Methods
        //----------------------------------------------------------------------------------------------------
        private int GetSelectedOrderID()
        {
            // Find the selected Order ID in the form variables, ensure it is
            // supplied and is an integer, return it as an integer.

            string selectedOrderID = Request.Form[SelectedOrderIDField];
            int orderId;

            if (selectedOrderID == null)
            {
                // This should not happen.
                throw new ApplicationException(string.Format(
                    "'{0}' was missing from Form fields.", SelectedOrderIDField));
            }

            if (int.TryParse(selectedOrderID, out orderId))
            {
                return orderId;
            }
            else
            {
                throw new ApplicationException(string.Format(
                    "The value of the '{0}' Form field must be an integer.  The value '{1}' is invalid.",
                    SelectedOrderIDField, selectedOrderID));
            }
        }
        //----------------------------------------------------------------------------------------------------
        #endregion
    }
}
